==> bonita-server-7.7.4-sources.jar: org/bonitasoft/engine/core/contract/data/SATaskContractData.java <==
/**
 * Copyright (C) 2015 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.core.contract.data;

import org.bonitasoft.engine.persistence.ArchivedPersistentObject;
import org.bonitasoft.engine.persistence.PersistentObject;

/**
 * @author Matthieu Chaffotte
 */
public class SATaskContractData extends SAContractData implements ArchivedPersistentObject {

    private static final long serialVersionUID = 5105634271134688723L;

    public SATaskContractData() {
        super();
    }

    public SATaskContractData(final SContractData contractData) {
        super(contractData);
    }

    public SATaskContractData(final STaskContractData taskContractData) {
        super(taskContractData);
    }

    @Override
    public Class<? extends PersistentObject> getPersistentObjectInterface() {
        return SATaskContractData.class;
    }

    public long getUserTaskId() {
        return scopeId;
    }
}

==> bonita-server-7.9.1-sources.jar: org/bonitasoft/engine/core/contract/data/SATaskContractData.java <==
/**
 * Copyright (C) 2015 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.core.contract.data;

import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import org.bonitasoft.engine.persistence.ArchivedPersistentObject;
import org.bonitasoft.engine.persistence.PersistentObject;

/**
 * @author Matthieu Chaffotte
 */
@Data
@NoArgsConstructor
@EqualsAndHashCode(callSuper = true)
public class SATaskContractData extends SAContractData implements ArchivedPersistentObject {

    public SATaskContractData(final SContractData contractData) {
        super(contractData);
    }

    public SATaskContractData(final STaskContractData taskContractData) {
        super(taskContractData);
    }

    @Override
    public Class<? extends PersistentObject> getPersistentObjectInterface() {
        return SATaskContractData.class;
    }

}
